# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .chat_completion_prediction_content_param_content import ChatCompletionPredictionContentParamContent
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ChatCompletionPredictionContentParam(UncheckedBaseModel):
    content: ChatCompletionPredictionContentParamContent
    type: typing.Literal["content"] = "content"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
