# This file was auto-generated by Fern from our API Definition.

import typing

FileProcessingStatus = typing.Union[typing.Literal["pending", "parsing", "embedding", "completed", "error"], typing.Any]
