# This file was auto-generated by Fern from our API Definition.

import typing
from .base_64_image import Base64Image
from .letta_image import LettaImage
from .url_image import UrlImage

ImageContentSource = typing.Union[Base64Image, LettaImage, UrlImage]
