# This file was auto-generated by Fern from our API Definition.

import typing

AgentType = typing.Union[
    typing.Literal[
        "memgpt_agent",
        "memgpt_v2_agent",
        "react_agent",
        "workflow_agent",
        "split_thread_agent",
        "sleeptime_agent",
        "voice_convo_agent",
        "voice_sleeptime_agent",
    ],
    typing.Any,
]
